summaryrefslogtreecommitdiffstats
path: root/kstars/kstars/skymap.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 04:44:41 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 04:44:41 +0000
commita374efce3a207b39514be3c52264091400ce297e (patch)
tree77bdf654b55826d4f59b53a5621310206bcaead1 /kstars/kstars/skymap.h
parentf81a494f3957d5cf38c787973415597941934727 (diff)
downloadtdeedu-a374efce3a207b39514be3c52264091400ce297e.tar.gz
tdeedu-a374efce3a207b39514be3c52264091400ce297e.zip
TQt4 port kdeedu
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1236073 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kstars/kstars/skymap.h')
-rw-r--r--kstars/kstars/skymap.h35
1 files changed, 18 insertions, 17 deletions
diff --git a/kstars/kstars/skymap.h b/kstars/kstars/skymap.h
index b6badd3b..1a6acf0d 100644
--- a/kstars/kstars/skymap.h
+++ b/kstars/kstars/skymap.h
@@ -58,12 +58,13 @@ class DeepSkyObject;
class SkyMap : public TQWidget {
Q_OBJECT
+ TQ_OBJECT
public:
/**
*Constructor. Read stored settings from KConfig object (focus position,
*zoom factor, sky color, etc.). Run initPopupMenus().
*/
- SkyMap( KStarsData *d, TQWidget *parent=0, const char *name=0);
+ SkyMap( KStarsData *d, TQWidget *tqparent=0, const char *name=0);
/**
*Destructor (empty)
@@ -163,7 +164,7 @@ public:
*@note setDestination() emits the destinationChanged() SIGNAL,
*which triggers the TQT_SLOT function SkyMap::slewFocus(). This
*function iteratively steps the Focus point toward Destination,
- *repainting the sky at each step (if Options::useAnimatedSlewing()==true).
+ *tqrepainting the sky at each step (if Options::useAnimatedSlewing()==true).
*@param f a pointer to the SkyPoint the map should slew to
*/
void setDestination( SkyPoint *f );
@@ -368,7 +369,7 @@ public:
*/
bool isAngleMode() const {return angularDistanceMode;}
-/**@short update the geometry of the angle ruler
+/**@short update the tqgeometry of the angle ruler
*/
void updateAngleRuler();
@@ -388,7 +389,7 @@ public:
/**@short Draw the current Sky map to a pixmap which is to be printed or exported to a file.
*
*Each of the draw functions is called, with a value for the Scale parameter computed to fit the
- *geometry of the TQPaintDevice.
+ *tqgeometry of the TQPaintDevice.
*@param pd pointer to the TQPaintDevice on which to draw.
*@see KStars::slotExportImage()
*@see KStars::slotPrint()
@@ -406,7 +407,7 @@ public slots:
*/
virtual void setGeometry( const TQRect &r );
-/**Recalculates the positions of objects in the sky, and then repaints the sky map.
+/**Recalculates the positions of objects in the sky, and then tqrepaints the sky map.
*If the positions don't need to be recalculated, use update() instead of forceUpdate().
*This saves a lot of CPU time.
*@param now if true, paintEvent() is run immediately. Otherwise, it is added to the event queue
@@ -427,13 +428,13 @@ public slots:
*simply assigned the nearest stored value. The precaclulated values are stored in the
*RefractCorr1 and RefractCorr2 arrays, and these are initialized in the SkyMap constructor.
*
*There are two cases: the true altitude is known, and the apparent altitude is needed;
*or the apparent altitude is known and the true altitude is needed.
*@param alt The input altitude
*@param findApparent if TRUE, then alt is the true altitude, and we'll find the apparent alt.
*@return the corrected altitude, as a dms object.
*/
- dms refract( const dms *alt, bool findApparent );
+ dms refract( const dms *alt, bool findAptqparent );
/**Step the Focus point toward the Destination point. Do this iteratively, redrawing the Sky
*Map after each step, until the Focus point is within 1 step of the Destination point.
@@ -554,7 +555,7 @@ protected:
*@li +/- keys Zoom in and out
*@li N/E/S/W keys Go to the cardinal points on the Horizon
*@li Z Go to the Zenith
- *@li <i>Space</i> Toggle between Horizontal and Equatorial coordinate systems
+ *@li <i>Space</i> Toggle betweenQt::Horizontal and Equatorial coordinate systems
*@li 0-9 Go to a major Solar System body (0=Sun; 1-9 are the major planets, except 3=Moon)
*@li [ Place starting point for measuring an angular distance
*@li ] End point for Angular Distance; display measurement.
@@ -622,7 +623,7 @@ private slots:
*/
void slotTransientLabel();
-/**Set the shape of mouse cursor to a cross with 4 arrows. */
+/**Set the tqshape of mouse cursor to a cross with 4 arrows. */
void setMouseMoveCursor();
private:
@@ -776,7 +777,7 @@ private:
void drawBoxes( TQPainter &p );
/**Draw symbols at the position of each Telescope currently being controlled by KStars.
- *@note The shape of the Telescope symbol is currently a hard-coded bullseye.
+ *@note The tqshape of the Telescope symbol is currently a hard-coded bullseye.
*@note there is no scale factor because this is only used for drawing onto the screen, not printing.
*@param psky reference to the TQPainter on which to draw (this should be the Sky pixmap).
*/
@@ -824,7 +825,7 @@ private:
*screen pixel coordinate offsets from the center of the Sky pixmap.
*@param dx horizontal pixel offset from center of SkyMap.
*@param dy vertical pixel offset from center of SkyMap.
- *@param Horiz if TRUE, the SkyMap is displayed using the Horizontal coordinate system
+ *@param Horiz if TRUE, the SkyMap is displayed using theQt::Horizontal coordinate system
*@param LSTh pointer to the local sidereal time, as a dms object.
*@param lat pointer to the current geographic laitude, as a dms object
*@param doRefraction if TRUE, correct for atmospheric refraction
@@ -853,7 +854,7 @@ private:
*exclude a large number of objects.
*
*Next, it determines if one of the poles of the current Coordinate System
- *(Equatorial or Horizontal) is currently inside the sky map window. This is
+ *(Equatorial orQt::Horizontal) is currently inside the sky map window. This is
*stored in the member variable 'bool SkyMap::isPoleVisible, and is set by the
*function SkyMap::setMapGeometry(), which is called by SkyMap::paintEvent().
*If a Pole is visible, then it will return TRUE immediately. The idea is that
@@ -900,11 +901,11 @@ private:
*/
double findPA( SkyObject *o, int x, int y, double scale=1.0 );
-/**@short Sets the shape of the default mouse cursor to a cross.
+/**@short Sets the tqshape of the default mouse cursor to a cross.
*/
void setDefaultMouseCursor();
-/**@short Sets the shape of the mouse cursor to a magnifying glass.
+/**@short Sets the tqshape of the mouse cursor to a magnifying glass.
*/
void setZoomMouseCursor();
@@ -919,7 +920,7 @@ private:
bool mouseButtonDown, midMouseButtonDown;
bool mouseMoveCursor; // true if mouseMoveEvent; needed by setMouseMoveCursor
bool slewing, clockSlewing;
- bool computeSkymap; //if false only old pixmap will repainted with bitBlt(), this saves a lot of cpu usage
+ bool computeSkymap; //if false only old pixmap will tqrepainted with bitBlt(), this saves a lot of cpu usage
bool angularDistanceMode;
int idSolInfo, idMessHST, idMoonInfo, idMoonImages, idMessInfo, idNGCHST;
int scrollCount;
@@ -427,13 +428,13 @@ public slots:
*RefractCorr1 and RefractCorr2 arrays, and these are initialized in the SkyMap constructor.
*
- *There are two cases: the true altitude is known, and the apparent altitude is needed;
- *or the apparent altitude is known and the true altitude is needed.
+ *There are two cases: the true altitude is known, and the aptqparent altitude is needed;
+ *or the aptqparent altitude is known and the true altitude is needed.
*@param alt The input altitude
@@ -427,13 +428,13 @@ public slots:
*@param alt The input altitude
- *@param findApparent if TRUE, then alt is the true altitude, and we'll find the apparent alt.
+ *@param findAptqparent if TRUE, then alt is the true altitude, and we'll find the aptqparent alt.
*@return the corrected altitude, as a dms object.
*/